==> owncloud-8.1.0p2.tgz: owncloud/apps/files_external/l10n/az.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." : "Müraciət token-nin alınmasında səhv baş verdi. Əmin olun ki, sizin Dropbox proqraminin açarı və gizlisi düzgündür.",
    "Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." : "Müraciət token-nin alınmasında səhv baş verdi. Əmin olun ki, sizin Dropbox proqraminin açarı və gizlisi düzgündür.",
    "Please provide a valid Dropbox app key and secret." : "Xahiş olunur düzgün Dropbox proqram açarı və gizlisini təqdim edəsiniz.",
    "Step 1 failed. Exception: %s" : "1-ci addım səhv oldu. İstisna: %s",
    "Step 2 failed. Exception: %s" : "2-ci addım. İstisna: %s",
    "External storage" : "Kənar informasıya daşıyıcısı",
    "Local" : "Yerli",
    "Location" : "Yerləşdiyiniz ünvan",
    "Amazon S3" : "Amazon S3",
    "Key" : "Açar",
    "Secret" : "Gizli",
    "Bucket" : "Vedrə",
    "Amazon S3 and compliant" : "Amazon S3 və uyğun",
    "Access Key" : "Yetki açarı",
    "Secret Key" : "Gizli açar",
    "Hostname" : "Sahibadı",
    "Port" : "Port",
    "Region" : "Ərazi",
    "Enable SSL" : "SSL-i işə sal",
    "Enable Path Style" : "Ünvan stilini işə sal",
    "App key" : "Proqram açarı",
    "App secret" : "Proqram sirri",
    "Host" : "Şəbəkədə ünvan",
    "Username" : "İstifadəçi adı",
    "Password" : "Şifrə",
    "Remote subfolder" : "Uzaq altqovluğu",
    "Secure ftps://" : "Təhlükəsiz ftps://",
    "Client ID" : "Müştəri İD-s",
    "Client secret" : "Müxtəri sirri",
    "OpenStack Object Storage" : "OpenStack Obyekt Deposu",
    "Region (optional for OpenStack Object Storage)" : "Ərazi(İstəkdən asılı olaraq OpenStack Obyekt Deposu üçündür)",
    "API Key (required for Rackspace Cloud Files)" : "API açar (Rackspace Cloud Fayllar üçün tələb edilir)",
    "Tenantname (required for OpenStack Object Storage)" : "Kirayəçiadı (OpenStack Obyekt Deposu üçün tələb edilir)",
    "Password (required for OpenStack Object Storage)" : "Şifrə (OpenStack Obyekt Deposu üçün tələb edilir)",
    "Service Name (required for OpenStack Object Storage)" : "Servis adi (OpenStack Obyekt Deposu üçün tələb edilir)",
    "URL of identity endpoint (required for OpenStack Object Storage)" : "Şəxsiyyətin son nöqtəsi URL-i (OpenStack Obyekt Deposu üçün tələb edilir)",
    "Timeout of HTTP requests in seconds" : "HTTP müraciətlər üçün saniyələrlə olan vaxtın bitməsi",
    "Share" : "Yayımla",
    "SMB / CIFS using OC login" : "OC login istifadə edir SMB / CIFS",
    "Username as share" : "Paylaşım üçün istifadəçi adı",
    "URL" : "URL",
    "Secure https://" : "Təhlükəsiz https://",
    "Public key" : "İctimai açar",
    "Storage with id \"%i\" not found" : "\"%i\"-li depo tapılmadı",
    "Invalid mount point" : "Yalnış mount nöqtəsi",
    "Invalid storage backend \"%s\"" : "Yalnış depo arxasonu \"%s\"",
    "Access granted" : "Yetki verildi",
    "Error configuring Dropbox storage" : "Dropbox deposunun konfiqurasiyasında səhv baş verdi",
    "Grant access" : "Yetkinin verilməsi",
    "Error configuring Google Drive storage" : "Google Drive deposunun konfiqində səgv baş verdi",
    "Personal" : "Şəxsi",
    "System" : "Sistem",
    "All users. Type to select user or group." : "Sistem istifadəçiləri. Daxil edin ki, istifadəçi və ya qrupu seçəsiniz.",
    "(group)" : "(qrup)",
    "Saved" : "Saxlanıldı",
    "Generate keys" : "Açarları generasiya et",
    "Error generating key pair" : "Açar cütlüyünün generasiyası səhvi",
    "<b>Note:</b> " : "<b>Qeyd:</b> ",
    "and" : "və",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Qeyd:</b> PHP-də cURL dəstəyi aktiv deyil və ya yüklənməyib. %s -in birləşdirilməsi mümkün deyil. Xahiş edilir onun yüklənilməsi barəsində inzibatşınıza məlumat verəsiniz.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Qeyd:</b> PHP-də FTP dəstəyi aktiv deyil və ya yüklənməyib. %s -in birləşdirilməsi mümkün deyil. Xahiş edilir onun yüklənilməsi barəsində inzibatşınıza məlumat verəsiniz.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Qeyd:</b> \"%s\" yüklənməyib. %s -in birləşdirilməsi mümkün deyil. Xahiş edilir onun yüklənilməsi barəsində inzibatşınıza məlumat verəsiniz.",
    "No external storage configured" : "Kənar depo konfiq edilməyib",
    "You can add external storages in the personal settings" : "Siz şəxsi quraşdırmalarınızda kənar depo əlavə edə bilərsiniz",
    "Name" : "Ad",
    "Storage type" : "Depo tipi",
    "Scope" : "Həcm",
    "External Storage" : "Kənar depo",
    "Folder name" : "Qovluq adı",
    "Configuration" : "Konfiqurasiya",
    "Available for" : "Üçün mövcuddur",
    "Add storage" : "Deponu əlavə et",
    "Advanced settings" : "İrəliləmiş quraşdırmalar",
    "Delete" : "Sil",
    "Enable User External Storage" : "İstifadəçi kənar deponu aktivləşdir",
    "Allow users to mount the following external storage" : "Göstərilən kənar deponun bərkidilməsi üçün istifadəçilərə izin ver"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/files_external/l10n/az.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "1-ci addım səhv oldu. İstisna: %s",
    "Step 2 failed. Exception: %s" : "2-ci addım. İstisna: %s",
    "External storage" : "Kənar informasıya daşıyıcısı",
    "Storage with id \"%i\" not found" : "\"%i\"-li depo tapılmadı",
    "Invalid mount point" : "Yalnış mount nöqtəsi",
    "Invalid storage backend \"%s\"" : "Yalnış depo arxasonu \"%s\"",
    "Personal" : "Şəxsi",
    "System" : "Sistem",
    "Grant access" : "Yetkinin verilməsi",
    "Access granted" : "Yetki verildi",
    "Generate keys" : "Açarları generasiya et",
    "Error generating key pair" : "Açar cütlüyünün generasiyası səhvi",
    "All users. Type to select user or group." : "Sistem istifadəçiləri. Daxil edin ki, istifadəçi və ya qrupu seçəsiniz.",
    "(group)" : "(qrup)",
    "Saved" : "Saxlanıldı",
    "None" : "Heç bir",
    "App key" : "Proqram açarı",
    "App secret" : "Proqram sirri",
    "Client ID" : "Müştəri İD-s",
    "Client secret" : "Müxtəri sirri",
    "Username" : "İstifadəçi adı",
    "Password" : "Şifrə",
    "Public key" : "İctimai açar",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Vedrə",
    "Hostname" : "Sahibadı",
    "Port" : "Port",
    "Region" : "Ərazi",
    "Enable SSL" : "SSL-i işə sal",
    "Enable Path Style" : "Ünvan stilini işə sal",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Uzaq altqovluğu",
    "Secure https://" : "Təhlükəsiz https://",
    "Dropbox" : "Dropbox",
    "Host" : "Şəbəkədə ünvan",
    "Secure ftps://" : "Təhlükəsiz ftps://",
    "Local" : "Yerli",
    "Location" : "Yerləşdiyiniz ünvan",
    "Share" : "Yayımla",
    "SMB / CIFS using OC login" : "OC login istifadə edir SMB / CIFS",
    "Username as share" : "Paylaşım üçün istifadəçi adı",
    "OpenStack Object Storage" : "OpenStack Obyekt Deposu",
    "<b>Note:</b> " : "<b>Qeyd:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Qeyd:</b> PHP-də cURL dəstəyi aktiv deyil və ya yüklənməyib. %s -in birləşdirilməsi mümkün deyil. Xahiş edilir onun yüklənilməsi barəsində inzibatşınıza məlumat verəsiniz.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Qeyd:</b> PHP-də FTP dəstəyi aktiv deyil və ya yüklənməyib. %s -in birləşdirilməsi mümkün deyil. Xahiş edilir onun yüklənilməsi barəsində inzibatşınıza məlumat verəsiniz.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Qeyd:</b> \"%s\" yüklənməyib. %s -in birləşdirilməsi mümkün deyil. Xahiş edilir onun yüklənilməsi barəsində inzibatşınıza məlumat verəsiniz.",
    "No external storage configured" : "Kənar depo konfiq edilməyib",
    "You can add external storages in the personal settings" : "Siz şəxsi quraşdırmalarınızda kənar depo əlavə edə bilərsiniz",
    "Name" : "Ad",
    "Storage type" : "Depo tipi",
    "Scope" : "Həcm",
    "External Storage" : "Kənar depo",
    "Folder name" : "Qovluq adı",
    "Configuration" : "Konfiqurasiya",
    "Available for" : "Üçün mövcuddur",
    "Advanced settings" : "İrəliləmiş quraşdırmalar",
    "Delete" : "Sil",
    "Add storage" : "Deponu əlavə et",
    "Enable User External Storage" : "İstifadəçi kənar deponu aktivləşdir",
    "Allow users to mount the following external storage" : "Göstərilən kənar deponun bərkidilməsi üçün istifadəçilərə izin ver"
},
"nplurals=2; plural=(n != 1);");
